==> keyclic_sdk_api-1.41.8%2B1.tar.gz: lib/model/category_patch.dart <==
part of keyclic_sdk_api.api;

class CategoryPatch {
  CategoryPatch({
    this.color,
    this.icon,
    this.identificationNumber,
    this.name,
  });

  CategoryPatch.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return;
    }
    color = json['color'];
    icon = json['icon'];
    identificationNumber = json['identificationNumber'];
    name = json['name'];
  }

  String color;

  String icon;

  String identificationNumber;

  String name;

  @override
  bool operator ==(dynamic other) {
    if (identical(this, other)) {
      return true;
    }

    return other is CategoryPatch && runtimeType == other.runtimeType;
  }

  @override
  int get hashCode => 0;

  Map<String, dynamic> toJson() {
    return {
      'color': color,
      'icon': icon,
      'identificationNumber': identificationNumber,
      'name': name,
    };
  }

  @override
  String toString() {
    return 'CategoryPatch[color=$color, icon=$icon, identificationNumber=$identificationNumber, name=$name, ]';
  }

  static List<CategoryPatch> listFromJson(List<dynamic> json) {
    return json == null
        ? List<CategoryPatch>()
        : json.map((value) => CategoryPatch.fromJson(value)).toList();
  }

  static Map<String, CategoryPatch> mapFromJson(Map<String, dynamic> json) {
    var map = Map<String, CategoryPatch>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) =>
          map[key] = CategoryPatch.fromJson(value));
    }
    return map;
  }
}

==> keyclic_sdk_api-2.0.3%2B1.tar.gz: lib/model/category_patch.dart <==
part of keyclic_sdk_api.api;

class CategoryPatch {
  CategoryPatch({
    this.color,
    this.icon,
    this.identificationNumber,
    this.name,
  });

  CategoryPatch.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return;
    }
    color = json['color'];
    icon = json['icon'];
    identificationNumber = json['identificationNumber'];
    name = json['name'];
  }

  String color;

  String icon;

  String identificationNumber;

  String name;

  @override
  bool operator ==(dynamic other) {
    // Same reference
    if (identical(this, other)) {
      return true;
    }

    return other is CategoryPatch &&
        runtimeType == other.runtimeType &&
        color == other.color &&
        icon == other.icon &&
        identificationNumber == other.identificationNumber &&
        name == other.name;
  }

  /// By default hashCode return reference
  @override
  int get hashCode =>
      0 ^
      color.hashCode ^
      icon.hashCode ^
      identificationNumber.hashCode ^
      name.hashCode;

  static List<CategoryPatch> listFromJson(List<dynamic> json) {
    return json == null
        ? <CategoryPatch>[]
        : json.map((value) => CategoryPatch.fromJson(value)).toList();
  }

  static Map<String, CategoryPatch> mapFromJson(Map<String, dynamic> json) {
    var map = Map<String, CategoryPatch>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) =>
          map[key] = CategoryPatch.fromJson(value));
    }
    return map;
  }

  Map<String, dynamic> toJson() {
    return {
      'color': color,
      'icon': icon,
      'identificationNumber': identificationNumber,
      'name': name,
    };
  }

  @override
  String toString() {
    return 'CategoryPatch[color=$color, icon=$icon, identificationNumber=$identificationNumber, name=$name, ]';
  }
}
